@@ -1,8 +1,9 @@
 "quacau" <-
-function(f,para) {
+function(f,para,paracheck=TRUE) {
     if(! check.fs(f)) return()
-    if(! are.parcau.valid(para)) return()
-
+    if(paracheck == TRUE) {
+      if(! are.parcau.valid(para)) return()
+    }
     U <- para$para[1]
     A <- para$para[2]
     n <- length(f)
