@@ -1,8 +1,9 @@
 "qualn3" <-
-function(f,para) {
-    
-    if(! are.parln3.valid(para)) return()
-
+function(f,para,paracheck=TRUE) {
+    if(! check.fs(f)) return()
+    if(paracheck == TRUE) {
+      if(! are.parln3.valid(para)) return()
+    }
     ZETA <- para$para[1]
     U  <- para$para[2]
     A  <- para$para[3]
